import { Component, OnInit, AfterViewInit, ViewChild, ElementRef, Inject } from '@angular/core';
import { DomSanitizer} from '@angular/platform-browser';
import { Renderer2 } from '@angular/core';
import { MatDialogRef,MAT_DIALOG_DATA } from '@angular/material';
import { SubmitAppService } from '../submit-app.service';
import { timer, Subscription} from 'rxjs';


@Component({
  selector: 'app-launch-dialog',
  templateUrl: './launch-dialog.component.html',
  styleUrls: ['./launch-dialog.component.css']
})
export class LaunchDialogComponent implements OnInit {
  batchcmdurl: string;
  appconfigurl: string;
  batchcmdsafeurl: any;
  appconfigsafeurl: any;
  rmListen: any;
  @ViewChild('launchbtn', { read: ElementRef })
  launchbtn: ElementRef;
  setFocus: Boolean;
  sub: Subscription;

  constructor( public dialogRef: MatDialogRef<LaunchDialogComponent>,
               private domSanitizer: DomSanitizer,
               private renderer: Renderer2,
               private submitAppService: SubmitAppService) {
      this.batchcmdurl = this.submitAppService.identity.value.site.url+"/"+this.submitAppService.app.value.name;
      this.batchcmdsafeurl = this.domSanitizer.bypassSecurityTrustResourceUrl(this.batchcmdurl);
      this.appconfigurl = this.submitAppService.app.value.url;
      if (!(this.appconfigurl == null)) {
       this.appconfigsafeurl = this.domSanitizer.bypassSecurityTrustResourceUrl(this.appconfigurl);
      }
      console.log('creating the laucnch dialog with urls',this.batchcmdsafeurl,this.appconfigsafeurl);

  }

  ngOnInit() {
    this.rmListen = this.renderer.listen('window','message',(event) => this.receiveMessage(event));
    this.setFocus = false;
    this.sub = this.submitAppService.readyToLaunch.subscribe((ready) => this.becomesReady(ready))
  }

  ngAfterViewInit() {
    console.log('in AfterViewInit, disabling the button');
    this.launchbtn.nativeElement._disabled = true;
  }
      

  cancel() {
    console.log('cause app cancel');
    this.submitAppService.submitcmd.next(null);
    this.submitAppService.appData.next(null)
    this.dialogRef.close()
  }

  launch() {
    console.log('cause app submission');
    this.dialogRef.close();
    this.submitAppService.launch();
  }

  
  ngOnDestroy() {
    console.log('dialog in onDestroy');
    this.rmListen();
    this.sub.unsubscribe();
  }





  becomesReady(ready) {
      
      if (this.launchbtn === undefined) {
          return
      }
      if (ready && !(this.setFocus)) {
        console.log('reenabling the launch button');
        this.launchbtn.nativeElement._disabled = false;
        this.launchbtn.nativeElement.focus();
        this.setFocus = true;
      } else {
        this.launchbtn.nativeElement._disabled = true;
          console.log('launch is still disabled');
      }
  }


  receiveMessage(event) {
      if (event.data['batchcmd'] !== undefined)  {
        this.submitAppService.submitcmd.next(event.data['batchcmd']);
      }
      if (event.data['appData'] !== undefined)  {
        this.submitAppService.appData.next(event.data['appData']);
      }
  }
}
